==> spyglass_neuro-0.4.2.tar.gz: spyglass_neuro-0.4.2/README.md <==
# spyglass

[![Import test](https://github.com/LorenFrankLab/spyglass/actions/workflows/workflow.yml/badge.svg)](https://github.com/LorenFrankLab/spyglass/actions/workflows/workflow.yml)

`spyglass` is a data analysis framework that facilitates the storage, analysis,
visualization, and sharing of neuroscience data to support reproducible
research. It is designed to be interoperable with the NWB format and integrates
open-source tools into a coherent framework.

Documentation can be found at -
[https://lorenfranklab.github.io/spyglass/](https://lorenfranklab.github.io/spyglass/)

## Installation

For installation instructions see -
[https://lorenfranklab.github.io/spyglass/latest/installation/](https://lorenfranklab.github.io/spyglass/latest/installation/)

## Tutorials

The tutorials for `spyglass` is currently in the form of Jupyter Notebooks and
can be found in the
[notebooks](https://github.com/LorenFrankLab/spyglass/tree/master/notebooks)
directory. We strongly recommend opening them in the context of `jupyterlab`.

## Contributing

See the [Developer's Note](https://lorenfranklab.github.io/spyglass/latest/contribute/)
for contributing instructions found at -
[https://lorenfranklab.github.io/spyglass/latest/contribute/](https://lorenfranklab.github.io/spyglass/latest/contribute/)

## License/Copyright

License and Copyright notice can be found at
[https://lorenfranklab.github.io/spyglass/latest/LICENSE/](https://lorenfranklab.github.io/spyglass/latest/LICENSE/)

## Citation

Kyu Hyun Lee, Eric Denovellis, Ryan Ly, Jeremy Magland, Jeff Soules, Alison
Comrie, Jennifer Guidera, Rhino Nevers, Daniel Gramling, Philip Adenekan, Ji
Hyun Bak, Emily Monroe, Andrew Tritt, Oliver Rübel, Thinh Nguyen, Dimitri
Yatsenko, Joshua Chu, Caleb Kemere, Samuel Garcia, Alessio Buccino, Emily Aery
Jones, Lisa Giocomo, and Loren Frank. Spyglass: A Data Analysis Framework for
Reproducible and Shareable Neuroscience Research. Neuroscience Meeting Planner.
San Diego, CA: Society for Neuroscience, 2022.

==> spyglass_neuro-0.4.3a2.tar.gz: spyglass_neuro-0.4.3a2/README.md <==
# spyglass

[![Import test](https://github.com/LorenFrankLab/spyglass/actions/workflows/workflow.yml/badge.svg)](https://github.com/LorenFrankLab/spyglass/actions/workflows/workflow.yml)

`spyglass` is a data analysis framework that facilitates the storage, analysis,
visualization, and sharing of neuroscience data to support reproducible
research. It is designed to be interoperable with the NWB format and integrates
open-source tools into a coherent framework.

Documentation can be found at -
[https://lorenfranklab.github.io/spyglass/](https://lorenfranklab.github.io/spyglass/)

## Installation

For installation instructions see -
[https://lorenfranklab.github.io/spyglass/latest/installation/](https://lorenfranklab.github.io/spyglass/latest/installation/)

## Tutorials

The tutorials for `spyglass` is currently in the form of Jupyter Notebooks and
can be found in the
[notebooks](https://github.com/LorenFrankLab/spyglass/tree/master/notebooks)
directory. We strongly recommend opening them in the context of `jupyterlab`.

## Contributing

See the
[Developer's Note](https://lorenfranklab.github.io/spyglass/latest/contribute/)
for contributing instructions found at -
[https://lorenfranklab.github.io/spyglass/latest/contribute/](https://lorenfranklab.github.io/spyglass/latest/contribute/)

## License/Copyright

License and Copyright notice can be found at
[https://lorenfranklab.github.io/spyglass/latest/LICENSE/](https://lorenfranklab.github.io/spyglass/latest/LICENSE/)

## Citation

Kyu Hyun Lee, Eric Denovellis, Ryan Ly, Jeremy Magland, Jeff Soules, Alison
Comrie, Jennifer Guidera, Rhino Nevers, Daniel Gramling, Philip Adenekan, Ji
Hyun Bak, Emily Monroe, Andrew Tritt, Oliver Rübel, Thinh Nguyen, Dimitri
Yatsenko, Joshua Chu, Caleb Kemere, Samuel Garcia, Alessio Buccino, Emily Aery
Jones, Lisa Giocomo, and Loren Frank. Spyglass: A Data Analysis Framework for
Reproducible and Shareable Neuroscience Research. Neuroscience Meeting Planner.
San Diego, CA: Society for Neuroscience, 2022.
